@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@ from locale import strcoll
 from urllib.parse import urlparse
 
 from eolie.helper_task import TaskHelper
-from eolie.define import El, Type, TimeSpan, TimeSpanValues, LoadingType
+from eolie.define import App, Type, TimeSpan, TimeSpanValues, LoadingType
 from eolie.utils import wanted_loading_type
 
 
@@ -71,22 +71,21 @@ class Row(Gtk.ListBoxRow):
         uri = item.get_property("uri")
         title = item.get_property("title")
         grid = Gtk.Grid()
+        grid.set_margin_start(5)
+        grid.set_margin_end(5)
         grid.set_column_spacing(10)
         grid.set_hexpand(True)
         grid.set_property("valign", Gtk.Align.CENTER)
         if item_type in [Type.BOOKMARK, Type.SEARCH, Type.HISTORY]:
             favicon = Gtk.Image()
-            favicon.set_margin_start(2)
             self.__set_favicon(favicon)
         elif item_type == Type.SUGGESTION:
             favicon = Gtk.Image.new_from_icon_name("system-search-symbolic",
                                                    Gtk.IconSize.MENU)
-            favicon.set_margin_start(2)
             favicon.show()
         elif item_type == Type.VIEW:
             favicon = Gtk.Image.new_from_icon_name("view-paged-symbolic",
                                                    Gtk.IconSize.MENU)
-            favicon.set_margin_start(2)
             favicon.show()
         if favicon is not None:
             grid.attach(favicon, 0, 0, 1, 2)
@@ -126,6 +125,7 @@ class Row(Gtk.ListBoxRow):
                                                      "user-trash-symbolic",
                                                      Gtk.IconSize.MENU)
             delete_button.get_image().set_opacity(0.5)
+            delete_button.set_margin_end(5)
             delete_button.set_property("valign", Gtk.Align.CENTER)
             delete_button.connect("clicked", self.__on_delete_clicked)
             delete_button.get_style_context().add_class("overlay-button")
@@ -137,6 +137,7 @@ class Row(Gtk.ListBoxRow):
                                                      "document-edit-symbolic",
                                                      Gtk.IconSize.MENU)
             edit_button.get_image().set_opacity(0.5)
+            edit_button.set_margin_end(5)
             edit_button.connect("clicked", self.__on_edit_clicked)
             edit_button.get_style_context().add_class("overlay-button")
             edit_button.set_property("valign", Gtk.Align.CENTER)
@@ -210,7 +211,7 @@ class Row(Gtk.ListBoxRow):
             @param uri as str
         """
         uri = self.__item.get_property("uri")
-        favicon_path = El().art.get_favicon_path(uri)
+        favicon_path = App().art.get_favicon_path(uri)
         if favicon_path is not None:
             favicon.set_from_file(favicon_path)
         else:
@@ -332,10 +333,6 @@ class Row(Gtk.ListBoxRow):
                                                     LoadingType.FOREGROUND)
                 if event.button == 2:
                     self.__window.close_popovers()
-            El().bookmarks.thread_lock.acquire()
-            El().bookmarks.set_access_time(uri, round(time(), 2))
-            El().bookmarks.set_more_popular(uri)
-            El().bookmarks.thread_lock.release()
         elif type_id == Type.VIEW:
             title = self.__item.get_property("title")
             for view in self.__window.container.views:
@@ -363,13 +360,13 @@ class Row(Gtk.ListBoxRow):
         self.__window.close_popovers()
         tag_id = self.__item.get_property("id")
         if tag_id == Type.POPULARS:
-            items = El().bookmarks.get_populars(50)
+            items = App().bookmarks.get_populars(50)
         elif tag_id == Type.RECENTS:
-            items = El().bookmarks.get_recents()
+            items = App().bookmarks.get_recents()
         elif tag_id == Type.UNCLASSIFIED:
-            items = El().bookmarks.get_unclassified()
+            items = App().bookmarks.get_unclassified()
         else:
-            items = El().bookmarks.get_bookmarks(tag_id)
+            items = App().bookmarks.get_bookmarks(tag_id)
         pages = []
         i = 0
         for (bid, uri, title) in items:
@@ -384,10 +381,10 @@ class Row(Gtk.ListBoxRow):
             @param button as Gtk.Button
         """
         history_id = self.__item.get_property("id")
-        guid = El().history.get_guid(history_id)
-        if El().sync_worker is not None:
-            El().sync_worker.remove_from_history(guid)
-        El().history.remove(history_id)
+        guid = App().history.get_guid(history_id)
+        if App().sync_worker is not None:
+            App().sync_worker.remove_from_history(guid)
+        App().history.remove(history_id)
         GLib.idle_add(self.destroy)
 
 
@@ -443,7 +440,7 @@ class UriPopover(Gtk.Popover):
         self.__bookmarks_box.bind_model(self.__bookmarks_model,
                                         self.__on_item_create)
         self.__calendar = builder.get_object("calendar")
-        if El().sync_worker is not None:
+        if App().sync_worker is not None:
             self.__sync_stack = builder.get_object("sync_stack")
             self.__sync_stack.show()
         self.add(builder.get_object("widget"))
@@ -456,7 +453,7 @@ class UriPopover(Gtk.Popover):
             @param child as str
         """
         # Add a new view for importing bookmarks
-        if child == "bookmarks" and not El().bookmarks.is_empty():
+        if child == "bookmarks" and not App().bookmarks.is_empty():
             grid = Gtk.Grid()
             image = Gtk.Image.new_from_icon_name("bookmark-new-symbolic",
                                                  Gtk.IconSize.BUTTON)
@@ -516,7 +513,7 @@ class UriPopover(Gtk.Popover):
                 item = Item()
                 item.set_property("type", Type.SUGGESTION)
                 item.set_property("title", value)
-                item.set_property("uri", El().search.get_search_uri(value))
+                item.set_property("uri", App().search.get_search_uri(value))
                 item.set_property("search", self.__search)
                 item.set_property("score", -1)
                 child = Row(item, self.__window)
@@ -663,7 +660,7 @@ class UriPopover(Gtk.Popover):
             Sync with Mozilla Sync
             @param button as Gtk.Button
         """
-        El().sync_worker.sync()
+        App().sync_worker.sync()
         GLib.timeout_add(1000, self.__check_sync_timer)
 
     def _on_import_button_clicked(self, button):
@@ -678,19 +675,18 @@ class UriPopover(Gtk.Popover):
 
     def _on_remove_button_clicked(self, button):
         """
-            Save bookmarks to tag
+            Remove bookmarks
             @param button as Gtk.Button
         """
-        El().bookmarks.thread_lock.acquire()
         for row in self.__bookmarks_box.get_selected_rows():
+            if App().sync_worker is not None:
+                guid = App().bookmarks.get_guid(self.__bookmark_id)
+                App().sync_worker.remove_from_bookmarks(guid)
             item_id = row.item.get_property("id")
-            El().bookmarks.delete(item_id)
+            App().bookmarks.remove(item_id)
             self.__bookmarks_box.remove(row)
             self.__remove_button.hide()
-        El().bookmarks.clean_tags()
-        if El().sync_worker is not None:
-            El().sync_worker.sync()
-        El().bookmarks.thread_lock.release()
+        App().bookmarks.clean_tags()
 
     def _on_tag_entry_enter_notify(self, entry, event):
         """
@@ -793,7 +789,7 @@ class UriPopover(Gtk.Popover):
                    _("Recent")),
                   (Type.UNCLASSIFIED,
                   _("Unclassified"))]
-        self.__add_tags(static + El().bookmarks.get_all_tags(), current)
+        self.__add_tags(static + App().bookmarks.get_all_tags(), current)
 
     def _on_day_selected(self, calendar):
         """
@@ -803,7 +799,7 @@ class UriPopover(Gtk.Popover):
         (year, month, day) = calendar.get_date()
         date = datetime(year, month + 1, day, 0, 0, tzinfo=tz.tzutc())
         atime = mktime(date.timetuple())
-        result = El().history.get(atime)
+        result = App().history.get(atime)
         self.__history_model.remove_all()
         self.__add_history_items(result, (year, month, day))
         self.__infobar.hide()
@@ -885,21 +881,18 @@ class UriPopover(Gtk.Popover):
             @param atime as double
             @thread safe
         """
-        history_ids = El().history.get_from_atime(atime)
-        El().history.clear_from(atime)
+        App().history.clear_from(atime)
         GLib.idle_add(self._on_day_selected, self.__calendar)
-        if El().sync_worker is None:
-            for history_id in El().history.get_empties():
-                El().history.remove(history_id)
-        else:
-            El().sync_worker.push_history(history_ids)
+        if App().sync_worker is not None:
+            for history_id in App().history.get_empties():
+                App().history.remove(history_id)
 
     def __check_sync_timer(self):
         """
             Check sync status, if sync, show spinner and reload
             else show sync button and quit
         """
-        if El().sync_worker.syncing:
+        if App().sync_worker.syncing:
             self.__sync_stack.set_visible_child_name("spinner")
             self.__sync_stack.get_visible_child().start()
             return True
@@ -929,12 +922,7 @@ class UriPopover(Gtk.Popover):
         """
         pos1 = row1.item.get_property("score")
         pos2 = row2.item.get_property("score")
-        if pos2 < 0:
-            return True
-        elif pos1 < 0:
-            return False
-        else:
-            return pos2 > pos1
+        return pos2 > pos1
 
     def __sort_tags(self, row1, row2):
         """
@@ -1077,10 +1065,10 @@ class UriPopover(Gtk.Popover):
         """
         self.__search = search
         if search == '':
-            result = El().history.search(search, 50)
+            result = App().history.search(search, 50)
         else:
-            result = El().history.search(search, 15)
-            result += El().bookmarks.search(search, 15)
+            result = App().history.search(search, 15)
+            result += App().bookmarks.search(search, 15)
 
         self.__add_searches(result, search)
 
@@ -1092,13 +1080,13 @@ class UriPopover(Gtk.Popover):
         self.__bookmarks_model.remove_all()
         self.__remove_button.hide()
         if tag_id == Type.POPULARS:
-            items = El().bookmarks.get_populars(50)
+            items = App().bookmarks.get_populars(50)
         elif tag_id == Type.RECENTS:
-            items = El().bookmarks.get_recents()
+            items = App().bookmarks.get_recents()
         elif tag_id == Type.UNCLASSIFIED:
-            items = El().bookmarks.get_unclassified()
+            items = App().bookmarks.get_unclassified()
         else:
-            items = El().bookmarks.get_bookmarks(tag_id)
+            items = App().bookmarks.get_bookmarks(tag_id)
         self.__bookmarks_count.set_text(_("%s bookmarks") % len(items))
         self.__add_bookmarks(items)
 
@@ -1157,18 +1145,16 @@ class UriPopover(Gtk.Popover):
             @param items [(bookmark_id, tag_id)] as [(int, int)]
             @param tag id as int
         """
-        El().bookmarks.thread_lock.acquire()
         tag_row = self.__tags_box.get_selected_row()
         current_tag_id = tag_row.item.get_property("id")
         for item in items:
             if current_tag_id >= 0:
-                El().bookmarks.del_tag_from(current_tag_id, item[0])
-            El().bookmarks.add_tag_to(item[1], item[0])
+                App().bookmarks.del_tag_from(current_tag_id, item[0])
+            App().bookmarks.add_tag_to(item[1], item[0])
         self.__on_row_activated(tag_row)
-        El().bookmarks.clean_tags()
-        if El().sync_worker is not None:
-            El().sync_worker.sync()
-        El().bookmarks.thread_lock.release()
+        App().bookmarks.clean_tags()
+        if App().sync_worker is not None:
+            App().sync_worker.sync()
 
     def __on_row_edited(self, row):
         """
