@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,14 +15,14 @@ from gi.repository import WebKit2, Gtk, Gio, Gdk, GLib
 from urllib.parse import urlparse
 from time import time
 
-from eolie.define import El, Indicator, LoadingType
-from eolie.utils import debug
+from eolie.define import App, Indicator, LoadingType
 from eolie.webview_errors import WebViewErrors
 from eolie.webview_navigation import WebViewNavigation
 from eolie.webview_signals import WebViewSignals
 from eolie.webview_artwork import WebViewArtwork
 from eolie.context import Context
 from eolie.list import LinkedList
+from eolie.logger import Logger
 
 
 class WebView(WebKit2.WebView):
@@ -88,7 +88,7 @@ class WebView(WebKit2.WebView):
             Update zoom level
         """
         try:
-            zoom_level = El().websettings.get_zoom(self.uri)
+            zoom_level = App().websettings.get_zoom(self.uri)
             if zoom_level is None:
                 zoom_level = 100
             if self.__related_view is None:
@@ -98,8 +98,8 @@ class WebView(WebKit2.WebView):
                 if window is not None and hasattr(window, "zoom_level"):
                     zoom_level *= window.zoom_level
         except Exception as e:
-            print("WebView::update_zoom_level()", e)
-        debug("Update zoom level: %s" % zoom_level)
+            Logger.error("WebView::update_zoom_level(): %s", e)
+        Logger.debug("Update zoom level: %s", zoom_level)
         self.set_zoom_level(zoom_level / 100)
 
     def print(self):
@@ -114,11 +114,11 @@ class WebView(WebKit2.WebView):
             Zoom in view
             @return current zoom after zoom in
         """
-        current = El().websettings.get_zoom(self.uri)
+        current = App().websettings.get_zoom(self.uri)
         if current is None:
             current = 100
         current += 10
-        El().websettings.set_zoom(current, self.uri)
+        App().websettings.set_zoom(current, self.uri)
         self.update_zoom_level()
         return current
 
@@ -127,13 +127,13 @@ class WebView(WebKit2.WebView):
             Zoom out view
             @return current zoom after zoom out
         """
-        current = El().websettings.get_zoom(self.uri)
+        current = App().websettings.get_zoom(self.uri)
         if current is None:
             current = 100
         current -= 10
         if current == 0:
             return 10
-        El().websettings.set_zoom(current, self.uri)
+        App().websettings.set_zoom(current, self.uri)
         self.update_zoom_level()
         return current
 
@@ -142,7 +142,7 @@ class WebView(WebKit2.WebView):
             Reset zoom level
             @return current zoom after zoom out
         """
-        El().websettings.set_zoom(100, self.uri)
+        App().websettings.set_zoom(100, self.uri)
         self.update_zoom_level()
 
     def set_title(self, title):
@@ -162,11 +162,11 @@ class WebView(WebKit2.WebView):
         self._uri = uri
         self.emit("uri-changed", uri)
 
-    def update_spell_checking(self):
+    def update_spell_checking(self, uri):
         """
             Update spell checking
         """
-        codes = El().websettings.get_languages(self.uri)
+        codes = App().websettings.get_languages(uri)
         # If None, default user language
         if codes is not None:
             self.get_context().set_spell_checking_languages(codes)
@@ -229,29 +229,33 @@ class WebView(WebKit2.WebView):
                 self.__text_entry = self.__text_entry.next
         return next
 
-    def stop_loading(self):
-        """
-            Keep stop loading state
-        """
-        self._cancelled = True
-        WebKit2.WebView.stop_loading(self)
-
-    def new_page(self, loading_type):
+    def new_page(self, uri, loading_type):
         """
             Open a new page
+            @param uri as uri
             @param loading_type as Gdk.LoadingType
         """
+        parsed = urlparse(uri)
+        if App().settings.get_value("adblock") and\
+                parsed.scheme in ["http", "https"] and\
+                not App().adblock_exceptions.find_parsed(parsed):
+            if App().adblock.is_netloc_blocked(parsed.netloc) or\
+                    App().adblock.is_uri_blocked(uri,
+                                                 parsed.netloc):
+                Logger.debug("WebView::new_page(): blocking %s ->%s",
+                             uri, self.uri)
+                return True
         if loading_type == LoadingType.POPOVER:
             if self.ephemeral:
                 webview = WebView.new_ephemeral(self._window, None)
             else:
                 webview = WebView.new(self._window, None)
             self._window.container.popup_webview(webview, True)
-            GLib.idle_add(webview.load_uri, self._navigation_uri)
+            GLib.idle_add(webview.load_uri, uri)
         else:
             self._new_pages_opened += 1
             webview = self._window.container.add_webview(
-                                                        self._navigation_uri,
+                                                        uri,
                                                         loading_type,
                                                         self.ephemeral,
                                                         None,
@@ -359,14 +363,6 @@ class WebView(WebKit2.WebView):
         """
         return self._shown
 
-    @property
-    def cancelled(self):
-        """
-            True if last loading was cancelled
-            @return bool
-        """
-        return self._cancelled
-
     @property
     def title(self):
         """
@@ -391,6 +387,16 @@ class WebView(WebKit2.WebView):
             uri = self._uri
         return uri
 
+    @property
+    def netloc(self):
+        """
+            Get netloc
+            @return str
+        """
+        uri = self.uri
+        parsed = urlparse(uri)
+        return parsed.netloc or ""
+
     @property
     def ephemeral(self):
         """
@@ -447,8 +453,6 @@ class WebView(WebKit2.WebView):
         self._title = None
         self._navigation_uri = None
         self.__related_view = related_view
-        self.__input_source = Gdk.InputSource.MOUSE
-        self._cancelled = False
         self._shown = False
         self.set_hexpand(True)
         self.set_vexpand(True)
@@ -458,35 +462,34 @@ class WebView(WebKit2.WebView):
         system = Gio.Settings.new("org.gnome.desktop.interface")
         animations = system.get_value("enable-animations")
         settings.set_property("enable-java",
-                              El().settings.get_value('enable-plugins'))
+                              App().settings.get_value('enable-plugins'))
         settings.set_property("enable-plugins",
-                              El().settings.get_value('enable-plugins'))
+                              App().settings.get_value('enable-plugins'))
         settings.set_property("minimum-font-size",
-                              El().settings.get_value(
+                              App().settings.get_value(
                                 "min-font-size").get_int32())
-        if El().settings.get_value("use-system-fonts"):
+        if App().settings.get_value("use-system-fonts"):
             self.__set_system_fonts(settings, system)
         else:
             settings.set_property("monospace-font-family",
-                                  El().settings.get_value(
+                                  App().settings.get_value(
                                     "font-monospace").get_string())
             settings.set_property("sans-serif-font-family",
-                                  El().settings.get_value(
+                                  App().settings.get_value(
                                     "font-sans-serif").get_string())
             settings.set_property("serif-font-family",
-                                  El().settings.get_value(
+                                  App().settings.get_value(
                                     "font-serif").get_string())
         settings.set_property("auto-load-images", True)
-        settings.set_property("enable-mediasource", True)
         settings.set_property("enable-media-stream", True)
         settings.set_property("enable-site-specific-quirks", True)
         settings.set_property("allow-universal-access-from-file-urls", False)
         settings.set_property("allow-file-access-from-file-urls", False)
         settings.set_property("enable-javascript", True)
         settings.set_property("enable-media-stream", True)
-        settings.set_property("enable-mediasource", True)
+        settings.set_property("enable-mediasource", False)
         settings.set_property("enable-developer-extras",
-                              El().settings.get_value("developer-extras"))
+                              App().settings.get_value("developer-extras"))
         settings.set_property("enable-offline-web-application-cache", True)
         settings.set_property("enable-page-cache", True)
         settings.set_property("enable-resizable-text-areas", True)
@@ -541,12 +544,42 @@ class WebView(WebKit2.WebView):
             @param related as WebView
             @param navigation_action as WebKit2.NavigationAction
         """
-        # Do not block if we get a click on view
-        elapsed = time() - related._last_click_time
-        popup_block = El().settings.get_value("popupblock")
-        parsed_related = urlparse(related.uri)
-        exception = El().popup_exceptions.find_parsed(parsed_related) or\
-            elapsed < 0.5
+        GLib.idle_add(self.__wait_for_uri, webview, related, navigation_action)
+
+    def __wait_for_uri(self, webview, related, navigation_action):
+        """
+            Add a new webview with related as soon an URI is available
+            @param webview as WebView
+            @param related as WebView
+            @param navigation_action as WebKit2.NavigationAction
+        """
+        uri = webview.uri
+        # We need an URI for adblocking
+        if not webview.uri:
+            GLib.idle_add(self.__wait_for_uri, webview,
+                          related, navigation_action)
+            return
+        # Block ads
+        parsed = urlparse(uri)
+        if App().settings.get_value("adblock") and\
+                parsed.scheme in ["http", "https"] and\
+                not App().adblock_exceptions.find_parsed(parsed):
+            if App().adblock.is_netloc_blocked(parsed.netloc) or\
+                    App().adblock.is_uri_blocked(uri,
+                                                 parsed.netloc):
+                Logger.debug("WebView::__wait_for_uri(): blocking %s ->%s",
+                             uri, self.uri)
+                webview.destroy()
+                return
+        popup_block = App().settings.get_value("popupblock")
+        if related.uri is not None:
+            parsed_related = urlparse(related.uri)
+            elapsed = time() - related._last_click_time
+            exception = elapsed < 0.5 or\
+                App().popup_exceptions.find_parsed(parsed_related)
+        else:
+            exception = False
+
         if not exception and popup_block and\
                 navigation_action.get_navigation_type() in [
                                WebKit2.NavigationType.OTHER,
@@ -594,6 +627,7 @@ class WebViewMeta(WebViewNavigation, WebView, WebViewErrors,
             @param webview as WebView
             @param event as WebKit2.LoadEvent
         """
+        self._uri = webview.get_uri()
         WebViewNavigation._on_load_changed(self, webview, event)
         WebViewSignals._on_load_changed(self, webview, event)
         WebViewArtwork._on_load_changed(self, webview, event)
