@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,9 +15,10 @@ from gi.repository import GLib, Gtk, Gio, WebKit2, Gdk
 from urllib.parse import urlparse
 from time import time
 
-from eolie.define import El, ADBLOCK_JS, LoadingType, EOLIE_DATA_PATH
+from eolie.define import App, ADBLOCK_JS, LoadingType, EOLIE_DATA_PATH
 from eolie.define import COOKIES_PATH
 from eolie.utils import get_ftp_cmd
+from eolie.logger import Logger
 
 
 class WebViewNavigation:
@@ -35,13 +36,11 @@ class WebViewNavigation:
             Init navigation
             @param related_view as WebView
         """
-        self.__js_timeout = None
         self.__related_view = related_view
         if related_view is None:
             self.__profile = None
         else:
             self.__profile = related_view.profile
-        self.__previous_uri = ""
         self.__insecure_content_detected = False
         self.connect("decide-policy", self.__on_decide_policy)
         self.connect("insecure-content-detected",
@@ -57,17 +56,18 @@ class WebViewNavigation:
             Load uri
             @param uri as str
         """
+        if App().phishing.is_phishing(uri):
+            self._show_phishing_error(uri)
+            return
         self._error = False
-        # Allow profile switching
-        self.__previous_uri = ""
         # If not an URI, start a search
         parsed = urlparse(uri)
         is_uri = parsed.scheme in ["about", "http",
                                    "https", "file", "populars"]
         if not is_uri and\
                 not uri.startswith("/") and\
-                El().search.is_search(uri):
-            uri = El().search.get_search_uri(uri)
+                App().search.is_search(uri):
+            uri = App().search.get_search_uri(uri)
         parsed = urlparse(uri)
         if uri == "about:blank":
             WebKit2.WebView.load_plain_text(self, "")
@@ -91,8 +91,8 @@ class WebViewNavigation:
             if parsed.scheme != "accept":
                 self.reset_bad_tls()
                 self.__insecure_content_detected = False
-            # Prevent cookies access on profile switching
             self.stop_loading()
+            self.__update_settings_for_uri(uri)
             GLib.idle_add(WebKit2.WebView.load_uri, self, uri)
 
     @property
@@ -112,97 +112,112 @@ class WebViewNavigation:
             @param webview as WebView
             @param event as WebKit2.LoadEvent
         """
-        uri = webview.uri
-        parsed = urlparse(uri)
-        if event == WebKit2.LoadEvent.STARTED:
-            self.set_setting("auto-load-images",
-                             not El().image_exceptions.find(parsed.netloc))
-            self._cancelled = False
-        elif event == WebKit2.LoadEvent.COMMITTED:
-            self.__hw_acceleration_policy(parsed.netloc)
-            self.content_manager.remove_all_style_sheets()
-            if El().phishing.is_phishing(uri):
-                self._show_phishing_error(uri)
-            else:
-                # Can't find a way to block content for ephemeral views
-                if El().settings.get_value("adblock") and\
-                        not El().adblock_exceptions.find_parsed(parsed) and\
-                        parsed.scheme in ["http", "https"] and\
-                        self.content_manager is not None:
-                    self.content_manager.add_style_sheet(
-                                                      El().default_style_sheet)
-                    rules = El().adblock.get_css_rules(uri)
-                    user_style_sheet = WebKit2.UserStyleSheet(
-                                 rules,
-                                 WebKit2.UserContentInjectedFrames.ALL_FRAMES,
-                                 WebKit2.UserStyleLevel.USER,
-                                 None,
-                                 None)
-                    self.content_manager.add_style_sheet(user_style_sheet)
-                self.update_zoom_level()
-                user_agent = El().websettings.get_user_agent(uri)
-                settings = self.get_settings()
-                if user_agent:
-                    settings.set_user_agent(user_agent)
-                else:
-                    settings.set_user_agent_with_application_details("Eolie",
-                                                                     None)
-                # Setup image blocker
-                self.set_setting("auto-load-images",
-                                 not El().image_exceptions.find(parsed.netloc))
-                # Setup eolie internal adblocker
-                if El().settings.get_value("adblock") and\
-                        parsed.scheme in ["http", "https"]:
-                    exception = El().adblock_exceptions.find_parsed(parsed)
-                    if not exception:
-                        noext = ".".join(parsed.netloc.split(".")[:-1])
-                        javascripts = ["adblock_%s.js" % parsed.netloc,
-                                       "adblock_%s.js" % noext]
-                        for javascript in javascripts:
-                            f = Gio.File.new_for_path("%s/%s" % (ADBLOCK_JS,
-                                                                 javascript))
-                            if f.query_exists():
-                                (status, content, tag) = f.load_contents(None)
-                                js = content.decode("utf-8")
-                                self.run_javascript(js, None, None)
-                                break
+        parsed = urlparse(self._uri)
+        if event == WebKit2.LoadEvent.COMMITTED:
+            http_scheme = parsed.scheme in ["http", "https"]
+            self.update_zoom_level()
+            # Setup eolie internal adblocker
+            if App().settings.get_value("adblock") and\
+                    http_scheme:
+                exception = App().adblock_exceptions.find_parsed(parsed)
+                if not exception:
+                    noext = ".".join(parsed.netloc.split(".")[:-1])
+                    javascripts = ["adblock_%s.js" % parsed.netloc,
+                                   "adblock_%s.js" % noext]
+                    for javascript in javascripts:
+                        f = Gio.File.new_for_path("%s/%s" % (ADBLOCK_JS,
+                                                             javascript))
+                        if f.query_exists():
+                            (status, content, tag) = f.load_contents(None)
+                            js = content.decode("utf-8")
+                            self.run_javascript(js, None, None)
+                            break
         elif event == WebKit2.LoadEvent.FINISHED:
+            self.update_spell_checking(self._uri)
             self.run_javascript_from_gresource(
                                   "/org/gnome/Eolie/Extensions.js", None, None)
-            self.set_favicon(False)
-            if parsed.scheme != "populars":
+            if parsed.scheme in ["http", "https"]:
                 self.set_snapshot()
-            self.update_spell_checking()
-            if El().show_tls:
+            if App().show_tls:
                 try:
                     from OpenSSL import crypto
                     from datetime import datetime
                     (valid, tls, errors) = webview.get_tls_info()
                     if tls is not None:
-                        print("***************************************"
-                              "***************************************")
+                        Logger.info("***************************************"
+                                    "***************************************")
                         cert_pem = tls.get_property("certificate-pem")
                         cert = crypto.load_certificate(crypto.FILETYPE_PEM,
                                                        cert_pem)
                         subject = cert.get_subject()
-                        print("CN: %s" % subject.CN)
+                        Logger.info("CN: %s", subject.CN)
                         start_bytes = cert.get_notBefore()
                         end_bytes = cert.get_notAfter()
                         start = datetime.strptime(start_bytes.decode("utf-8"),
                                                   "%Y%m%d%H%M%SZ")
                         end = datetime.strptime(end_bytes.decode("utf-8"),
                                                 "%Y%m%d%H%M%SZ")
-                        print("Valid from %s to %s" % (start, end))
-                        print("Serial number: %s" % cert.get_serial_number())
-                        print(cert_pem)
-                        print("***************************************"
-                              "***************************************")
+                        Logger.info("Valid from %s to %s", (start, end))
+                        Logger.info("Serial number: %s",
+                                    cert.get_serial_number())
+                        Logger.info(cert_pem)
+                        Logger.info("***************************************"
+                                    "***************************************")
                 except Exception as e:
-                    print("Please install OpenSSL python support:", e)
+                    Logger.info("Please install OpenSSL python support: %s", e)
 
 #######################
 # PRIVATE             #
 #######################
+    def __update_settings_for_uri(self, uri):
+        """
+            Update internal settings for URI
+            @param uri as str
+        """
+        parsed = urlparse(uri)
+        http_scheme = parsed.scheme in ["http", "https"]
+        App().history.set_page_state(uri)
+        self.__switch_profile(uri)
+        self.__update_bookmark_metadata(uri)
+        self.__hw_acceleration_policy(parsed.netloc)
+        self.content_manager.remove_all_style_sheets()
+        # Can't find a way to block content for ephemeral views
+        if App().settings.get_value("adblock") and\
+                not App().adblock_exceptions.find_parsed(parsed) and\
+                http_scheme and\
+                self.content_manager is not None:
+            self.content_manager.add_style_sheet(
+                                             App().default_style_sheet)
+            rules = App().adblock.get_css_rules(uri)
+            user_style_sheet = WebKit2.UserStyleSheet(
+                         rules,
+                         WebKit2.UserContentInjectedFrames.ALL_FRAMES,
+                         WebKit2.UserStyleLevel.USER,
+                         None,
+                         None)
+            self.content_manager.add_style_sheet(user_style_sheet)
+        user_agent = App().websettings.get_user_agent(uri)
+        settings = self.get_settings()
+        if user_agent:
+            settings.set_user_agent(user_agent)
+        else:
+            settings.set_user_agent_with_application_details("Eolie",
+                                                             None)
+        # Setup image blocker
+        block_image = http_scheme and\
+            App().settings.get_value("imageblock") and\
+            not App().image_exceptions.find_parsed(parsed)
+        self.set_setting("auto-load-images", not block_image)
+
+    def __update_bookmark_metadata(self, uri):
+        """
+            Update bookmark access time/popularity
+            @param uri as str
+        """
+        if App().bookmarks.get_id(uri) is not None:
+            App().bookmarks.set_access_time(uri, round(time(), 2))
+            App().bookmarks.set_more_popular(uri)
+
     def __hw_acceleration_policy(self, netloc):
         """
             Disable hw acceleration for blacklist
@@ -222,38 +237,17 @@ class WebViewNavigation:
         """
         if self.ephemeral or self.__related_view is not None:
             return
-        profile = El().websettings.get_profile(uri)
+        profile = App().websettings.get_profile(uri)
         if self.__profile != profile:
             self.__profile = profile
             cookie_manager = self.get_context().get_cookie_manager()
             path = COOKIES_PATH % (EOLIE_DATA_PATH, profile)
             cookie_manager.set_persistent_storage(
-                                        path,
-                                        WebKit2.CookiePersistentStorage.SQLITE)
-        self.get_context().clear_cache()
-
-    def __same_domain(self, parsed1, parsed2):
-        """
-            True if uri1 domain == uri2 domain
-            @param parsed1 as UrlParse
-            @param parsed2 as UrlParse
-            @return bool
-        """
-        # Profile management
-        # If root domain does not change, keep current profile
-        # Useful for auth scenario like with accounts.google.com
-        parsed_split1 = parsed1.netloc.split(".")
-        parsed_split2 = parsed2.netloc.split(".")
-        if len(parsed_split1) > 1 and\
-                len(parsed_split2) > 1 and\
-                parsed_split1[-2] == parsed_split2[-2]:
-            return True
-        return False
+                                    path,
+                                    WebKit2.CookiePersistentStorage.SQLITE)
 
     def __on_run_as_modal(self, webview):
-        """
-        """
-        print("WebView::__on_run_as_modal(): TODO")
+        Logger.info("WebView::__on_run_as_modal(): TODO")
 
     def __on_insecure_content_detected(self, webview, event):
         """
@@ -281,26 +275,18 @@ class WebViewNavigation:
 
     def __on_uri_changed(self, webview, param):
         """
-            Clear readable context and title
+            Stop running background task and update favicon
             @param webview as WebKit2.WebView
             @param param as GObject.ParamSpec
         """
         uri = webview.get_property(param.name)
-        parsed = urlparse(uri)
-        # Only switch profile if domain changed
-        previous_parsed = urlparse(self.__previous_uri)
-        switch_profile = not self.__same_domain(parsed, previous_parsed)
-        if switch_profile:
-            self.__switch_profile(uri)
         self.stop_snapshot()
-        self.stop_favicon()
-        self.__previous_uri = uri
         # JS bookmark (Bookmarklet)
         if not uri.startswith("javascript:"):
             self.emit("uri-changed", uri)
         # Js update, force favicon caching for current uri
         if not self.is_loading():
-            self.set_favicon(False)
+            self.set_favicon()
 
     def __on_title_changed(self, webview, param):
         """
@@ -308,16 +294,9 @@ class WebViewNavigation:
             @param webview as WebKit2.WebView
             @param param as GObject.ParamSpec
         """
-        if self.__js_timeout is not None:
-            GLib.source_remove(self.__js_timeout)
-            self.__js_timeout = None
         title = webview.get_property(param.name)
         if title:
             self.emit("title-changed", title)
-            self.__js_timeout = GLib.timeout_add(
-                                 2000,
-                                 self.__on_js_timeout,
-                                 "/org/gnome/Eolie/Readability.js")
 
     def __on_notify_favicon(self, webview, favicon):
         """
@@ -325,15 +304,7 @@ class WebViewNavigation:
             @param webview as WebView
             @param favicon as GObject.ParamSpec
         """
-        self.set_favicon(True)
-
-    def __on_js_timeout(self, path):
-        """
-            Run js
-            @param path as str
-        """
-        self.__js_timeout = None
-        self.run_javascript_from_gresource(path, None, None)
+        self.set_favicon()
 
     def __on_decide_policy(self, webview, decision, decision_type):
         """
@@ -362,7 +333,8 @@ class WebViewNavigation:
                                                uri,
                                                Gtk.get_current_event_time())
                     except Exception as e:
-                        print("WebViewNavigation::__on_decide_policy()", e)
+                        Logger.error("""WebViewNavigation::
+                                        __on_decide_policy(): %s""", e)
                     decision.ignore()
                 else:
                     decision.use()
@@ -373,27 +345,27 @@ class WebViewNavigation:
             return False
 
         navigation_action = decision.get_navigation_action()
-        self._navigation_uri = navigation_action.get_request().get_uri()
+        navigation_uri = navigation_action.get_request().get_uri()
         mouse_button = navigation_action.get_mouse_button()
-        parsed_navigation = urlparse(self._navigation_uri)
+        parsed_navigation = urlparse(navigation_uri)
         self.clear_text_entry()
         if parsed_navigation.scheme not in ["http", "https", "file", "about",
                                             "populars", "accept"]:
             try:
                 Gtk.show_uri_on_window(self._window,
-                                       self._navigation_uri,
+                                       navigation_uri,
                                        Gtk.get_current_event_time())
             except Exception as e:
-                print("WebViewNavigation::__on_decide_policy()", e)
+                Logger.error("WebViewNavigation::__on_decide_policy(): %s", e)
             decision.ignore()
         elif mouse_button == 0:
             # Prevent opening empty pages
-            if self._navigation_uri == "about:blank":
+            if navigation_uri == "about:blank":
                 self.reset_last_click_event()
                 decision.use()
                 return True
             elif decision_type == WebKit2.PolicyDecisionType.NEW_WINDOW_ACTION:
-                self.new_page(LoadingType.FOREGROUND)
+                self.new_page(navigation_uri, LoadingType.FOREGROUND)
                 decision.ignore()
                 return True
             else:
@@ -406,23 +378,28 @@ class WebViewNavigation:
                     loading_type = LoadingType.POPOVER
                 else:
                     loading_type = LoadingType.FOREGROUND
-                self.new_page(loading_type)
+                self.new_page(navigation_uri, loading_type)
                 decision.ignore()
                 return True
             elif self._window.modifiers & Gdk.ModifierType.CONTROL_MASK:
-                self.new_page(LoadingType.BACKGROUND)
+                self.new_page(navigation_uri, LoadingType.BACKGROUND)
                 decision.ignore()
                 return True
             elif self._window.modifiers & Gdk.ModifierType.SHIFT_MASK:
-                self.new_page(LoadingType.POPOVER)
+                self.new_page(navigation_uri, LoadingType.POPOVER)
                 decision.ignore()
                 return True
             else:
-                El().history.set_page_state(self._navigation_uri)
-                self._error = False
-                decision.use()
-                return False
+                self.__update_settings_for_uri(navigation_uri)
+                if App().phishing.is_phishing(navigation_uri):
+                    self._show_phishing_error(navigation_uri)
+                    decision.ignore()
+                    return True
+                else:
+                    self._error = False
+                    decision.use()
+                    return False
         else:
-            self.new_page(LoadingType.BACKGROUND)
+            self.new_page(navigation_uri, LoadingType.BACKGROUND)
             decision.ignore()
             return True
