@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -16,9 +16,10 @@ from gettext import gettext as _
 from urllib.parse import urlparse
 from time import time
 
-from eolie.define import El, LoadingType
+from eolie.define import App, LoadingType
 from eolie.utils import get_snapshot
 from eolie.search import Search
+from eolie.logger import Logger
 
 
 class WebViewMenuSignals:
@@ -51,7 +52,7 @@ class WebViewMenuSignals:
             return
         # HACK, don't know how to add web inspector
         inspector_item = None
-        if El().settings.get_value("developer-extras"):
+        if App().settings.get_value("developer-extras"):
             count = context_menu.get_n_items()
             if count > 0:
                 inspector_item = context_menu.get_item_at_position(count - 1)
@@ -60,7 +61,7 @@ class WebViewMenuSignals:
         if parsed.scheme == "populars":
             if hit.context_is_link():
                 action = Gio.SimpleAction(name="reload_preview")
-                El().add_action(action)
+                App().add_action(action)
                 action.connect("activate",
                                self.__on_reload_preview_activate,
                                hit.get_link_uri())
@@ -77,7 +78,7 @@ class WebViewMenuSignals:
             selection = user_data.get_string()
         if hit.context_is_link():
             action = Gio.SimpleAction(name="open_new_page")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_open_new_page_activate,
                            hit.get_link_uri(), False)
@@ -87,7 +88,7 @@ class WebViewMenuSignals:
                                              None)
             context_menu.append(item)
             action = Gio.SimpleAction(name="open_new_private_page")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_open_new_page_activate,
                            hit.get_link_uri(), True)
@@ -97,7 +98,7 @@ class WebViewMenuSignals:
                                          None)
             context_menu.append(item)
             action = Gio.SimpleAction(name="open_new_window")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_open_new_window_activate,
                            hit.get_link_uri())
@@ -110,7 +111,7 @@ class WebViewMenuSignals:
             context_menu.append(item)
         if selection:
             action = Gio.SimpleAction(name="copy_text")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_copy_text_activate,
                            selection)
@@ -123,7 +124,7 @@ class WebViewMenuSignals:
                 hit.context_is_image() or\
                 hit.context_is_media():
             action = Gio.SimpleAction(name="copy_link_uri")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_copy_link_uri_activate,
                            hit.get_link_uri() or
@@ -136,7 +137,7 @@ class WebViewMenuSignals:
             context_menu.append(item)
         if selection and hit.context_is_selection():
             action = Gio.SimpleAction(name="search_words")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_search_words_activate,
                            selection)
@@ -161,7 +162,7 @@ class WebViewMenuSignals:
                 msg = _("Download this file")
             if uri:
                 action = Gio.SimpleAction(name="download")
-                El().add_action(action)
+                App().add_action(action)
                 action.connect("activate",
                                self.__on_download_activate,
                                uri)
@@ -175,7 +176,7 @@ class WebViewMenuSignals:
             context_menu.append(item)
             # Save all images
             action = Gio.SimpleAction(name="save_imgs")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_save_images_activate)
             item = WebKit2.ContextMenuItem.new_from_gaction(
@@ -185,7 +186,7 @@ class WebViewMenuSignals:
             context_menu.append(item)
             # Save all videos
             action = Gio.SimpleAction(name="save_videos")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_save_videos_activate)
             item = WebKit2.ContextMenuItem.new_from_gaction(
@@ -195,7 +196,7 @@ class WebViewMenuSignals:
             context_menu.append(item)
             # Save page as image
             action = Gio.SimpleAction(name="save_as_image")
-            El().add_action(action)
+            App().add_action(action)
             action.connect("activate",
                            self.__on_save_as_image_activate)
             item = WebKit2.ContextMenuItem.new_from_gaction(
@@ -236,7 +237,7 @@ class WebViewMenuSignals:
             @param uri as str
             @param ephemeral as bool
         """
-        window = El().get_new_window()
+        window = App().get_new_window()
         window.container.add_webview(uri,
                                      LoadingType.FOREGROUND,
                                      self.ephemeral)
@@ -281,7 +282,7 @@ class WebViewMenuSignals:
         try:
             self.get_context().download_uri(uri)
         except Exception as e:
-            print("WebViewMenuSignals::__on_download_activate():", e)
+            Logger.error("WebViewMenuSignals::__on_download_activate(): %s", e)
 
     def __on_save_images_activate(self, action, variant):
         """
@@ -330,7 +331,8 @@ class WebViewMenuSignals:
             webview.load_uri(uri)
             webview.connect("load-changed", self.__on_load_changed, uri)
         except Exception as e:
-            print("WebViewMenuSignals::__on_reload_preview_activate():", e)
+            Logger.error("""WebViewMenuSignals::
+                            __on_reload_preview_activate(): %s""", e)
 
     def __on_load_changed(self, webview, event, uri):
         """
@@ -371,7 +373,7 @@ class WebViewMenuSignals:
                                  uri, False)
         else:
             if surface is not None:
-                El().art.save_artwork(uri, surface, "start")
+                App().art.save_artwork(uri, surface, "start")
                 self.reload()
             window = webview.get_toplevel()
             webview.destroy()
@@ -394,7 +396,7 @@ class WebViewMenuSignals:
                                    "file:///tmp/eolie_snapshot.png",
                                    Gtk.get_current_event_time())
         except Exception as e:
-            print("WebView::__on_snapshot():", e)
+            Logger.error("WebView::__on_snapshot(): %s", e)
             # The 32767 limit on the width/height dimensions
             # of an image surface is new in cairo 1.10,
             # try with WebKit2.SnapshotRegion.VISIBLE
