@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -12,11 +12,12 @@
 
 from gi.repository import Gtk, GLib, Gio, Gdk
 
-from eolie.define import El, Indicator, LoadingType
+from eolie.define import App, Indicator, LoadingType
 from eolie.toolbar import Toolbar
 from eolie.container import Container
 from eolie.utils import get_current_monitor_model, name_from_profile_id
 from eolie.helper_task import TaskHelper
+from eolie.logger import Logger
 
 
 class Window(Gtk.ApplicationWindow):
@@ -43,8 +44,7 @@ class Window(Gtk.ApplicationWindow):
         self.__window_state = 0
         self.__timeout_configure = None
         self.__setup_content()
-        self.__setup_window(size, maximized)
-        self.connect("realize", self.__on_realize)
+        self.connect("realize", self.__on_realize, size, maximized)
         self.connect("key-press-event", self.__on_key_press_event)
         self.connect("key-release-event", self.__on_key_release_event)
         self.connect("window-state-event", self.__on_window_state_event)
@@ -55,6 +55,7 @@ class Window(Gtk.ApplicationWindow):
                                                GLib.VariantType.new("s"))
         shortcut_action.connect("activate", self.__on_shortcut_action)
         self.add_action(shortcut_action)
+        self.set_auto_startup_notification(False)
 
     def update_zoom_level(self, force):
         """
@@ -103,7 +104,7 @@ class Window(Gtk.ApplicationWindow):
         self.disconnect_by_func(self.__on_motion_notify_event)
         GLib.idle_add(self.__fullscreen_toolbar.destroy)
         GLib.idle_add(self.__fullscreen_revealer.destroy)
-        if El().settings.get_value("show-sidebar"):
+        if App().settings.get_value("show-sidebar"):
             self.__container.sites_manager.show()
         self.__fullscreen_toolbar = None
         self.__fullscreen_revealer = None
@@ -127,26 +128,26 @@ class Window(Gtk.ApplicationWindow):
         uri = webview.uri
         if uri is not None:
             self.toolbar.title.set_uri(uri)
-            accept_tls = El().websettings.get_accept_tls(uri)
+            accept_tls = App().websettings.get_accept_tls(uri)
             self.toolbar.end.show_tls_button(accept_tls)
-        self.toolbar.title.update_load_indicator(webview)
         if webview.popups:
             self.toolbar.title.show_indicator(Indicator.POPUPS)
         else:
             self.toolbar.title.show_indicator(Indicator.NONE)
         if webview.is_loading():
-            self.toolbar.title.show_spinner(True)
+            self.toolbar.title.set_loading(True)
             self.toolbar.title.progress.show()
         else:
             self.toolbar.title.progress.hide()
+            self.toolbar.title.set_loading(False)
             readable_content = webview.readable_content
             self.toolbar.title.show_readable_button(readable_content != "")
         profile = name_from_profile_id(webview.profile)
         title = webview.title
         if title:
-            self.toolbar.title.set_title("%s%s" % (profile, title))
+            self.toolbar.title.set_title(profile, title)
         elif uri:
-            self.toolbar.title.set_title("%s%s" % (profile, uri))
+            self.toolbar.title.set_title(profile, uri)
         self.toolbar.actions.set_actions(webview)
 
     def hide(self):
@@ -248,7 +249,7 @@ class Window(Gtk.ApplicationWindow):
             Update zoom level for default screen
         """
         monitor_model = get_current_monitor_model(self)
-        zoom_levels = El().settings.get_value(
+        zoom_levels = App().settings.get_value(
                                          "default-zoom-level")
         user_zoom_level = False
         for zoom_level in zoom_levels:
@@ -286,7 +287,7 @@ class Window(Gtk.ApplicationWindow):
             if maximized:
                 self.maximize()
         except Exception as e:
-            print("Window::__setup_window():", e)
+            Logger.error("Window::__setup_window(): %s", e)
 
     def __on_configure_event(self, window, event):
         """
@@ -319,7 +320,7 @@ class Window(Gtk.ApplicationWindow):
             appinfo = Gio.app_info_get_default_for_type("text/plain", False)
             appinfo.launch([tmp], None)
         except Exception as e:
-            print("Window::__on_source_loaded():", e)
+            Logger.error("Window::__on_source_loaded(): %s", e)
 
     def __on_configure_timeout(self):
         """
@@ -360,11 +361,14 @@ class Window(Gtk.ApplicationWindow):
             if not lock:
                 self.__fullscreen_revealer.set_reveal_child(False)
 
-    def __on_realize(self, widget):
+    def __on_realize(self, widget, size, maximized):
         """
             Update zoom level
             @param widget as Gtk.Widget
+            @param size as (int, int)
+            @param maximized as bool
         """
+        self.__setup_window(size, maximized)
         self.update_zoom_level(False)
 
     def __on_key_press_event(self, window, event):
@@ -413,9 +417,10 @@ class Window(Gtk.ApplicationWindow):
             else:
                 self.fullscreen()
         elif string == "quit":
-            El().quit(True)
+            App().quit(True)
         elif string == "new_page":
-            self.container.add_webview(El().start_page, LoadingType.FOREGROUND)
+            self.container.add_webview(App().start_page,
+                                       LoadingType.FOREGROUND)
         elif string == "close_page":
             if self.is_fullscreen:
                 self.container.current.webview.emit("leave-fullscreen")
@@ -424,7 +429,7 @@ class Window(Gtk.ApplicationWindow):
         elif string == "reload":
             self.container.current.webview.reload()
         elif string == "home":
-            self.container.current.webview.load_uri(El().start_page)
+            self.container.current.webview.load_uri(App().start_page)
         elif string == "source":
             uri = self.container.current.webview.uri
             task_helper = TaskHelper()
@@ -448,11 +453,11 @@ class Window(Gtk.ApplicationWindow):
         elif string == "print":
             self.container.current.webview.print()
         elif string == "private":
-            self.container.add_webview(El().start_page,
+            self.container.add_webview(App().start_page,
                                        LoadingType.FOREGROUND,
                                        True)
         elif string == "last_page":
-            El().pages_menu.activate_last_action()
+            App().pages_menu.activate_last_action()
         elif string == "zoom_in":
             self.container.current.webview.zoom_in()
         elif string == "zoom_out":
@@ -468,10 +473,30 @@ class Window(Gtk.ApplicationWindow):
         elif string == "expose":
             active = self.toolbar.actions.view_button.get_active()
             self.toolbar.actions.view_button.set_active(not active)
+        elif string == "jsblock":
+            current_webview = self.container.current.webview
+            App().helper.call("EnableJS",
+                              current_webview.get_page_id(),
+                              GLib.Variant("(s)", (current_webview.netloc,)),
+                              self.__on_js_enabled,
+                              current_webview)
         elif string == "show_left_panel":
-            value = El().settings.get_value("show-sidebar")
-            El().settings.set_value("show-sidebar",
-                                    GLib.Variant("b", not value))
+            value = App().settings.get_value("show-sidebar")
+            App().settings.set_value("show-sidebar",
+                                     GLib.Variant("b", not value))
+        elif string == "mse_enabled":
+            self.container.current.webview.set_setting("enable-mediasource",
+                                                       True)
+            self.container.current.webview.reload()
+
+    def __on_js_enabled(self, proxy, task, webview):
+        """
+            Reload page
+            @param proxy as Gio.DBusProxy
+            @param task as Gio.Task
+            @param webview as WebView
+        """
+        webview.reload()
 
     def __on_popover_closed(self, popover):
         """
